@@ -687,7 +687,6 @@ class VacBot():
     def request_all_statuses(self):
         self.refresh_statuses()
         self.refresh_components()
-        self.refresh_liveMap()
 
 	#Common ecovacs commands
     def Clean(self, type='auto'):
@@ -773,7 +772,7 @@ class VacBot():
         return dec.decompress(finalArray)
 
     def CreatePNGMap(self):
-        im = Image.new("RGB", (6400, 6400))
+        im = Image.new("RGBA", (6400, 6400))
         draw = ImageDraw.Draw(im)
 
         imageX = 0
